@@ -2,7 +2,7 @@
 /*
  *  cstring.h
  *
- *  Copyright (c) 2004 - 2008, clown. All rights reserved.
+ *  Copyright (c) 2004 - 2010, clown. All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -29,23 +29,13 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Tue 07 Oct 2008 11:09:00 JST
+ *  Last-modified: Fri 30 Jul 2010 22:38:00 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_CSTRING_H
 #define CLX_CSTRING_H
 
-#ifndef CLX_WIN32
-//#if defined(_MSC_VER) && (_MSC_VER >= 1200)
-#if defined(_WIN32) || defined(__WIN32__) || defined(WIN32)
-#define CLX_WIN32
-#endif
-#endif // CLX_WIN32
-
-#if defined(_MSC_VER) && (_MSC_VER >= 1200)
-#pragma warning(disable: 4996)
-#endif
-
+#include "config.h"
 #include <ctime>
 #include <cstring>
 #include <cstdlib>
@@ -213,14 +203,14 @@ namespace clx {
 	/* --------------------------------------------------------------------- */
 	//  strftime
 	/* --------------------------------------------------------------------- */
-	inline size_t strftime(wchar_t* str, size_t n, const wchar_t* fmt, const tm* tmptr) {
+	inline std::size_t strftime(wchar_t* str, std::size_t n, const wchar_t* fmt, const std::tm* tmptr) {
 		return std::wcsftime(str, n, fmt, tmptr);
 	}
 	
 	/* --------------------------------------------------------------------- */
 	//  strxfrm
 	/* --------------------------------------------------------------------- */
-	inline size_t strxfrm(wchar_t* dest, const wchar_t* src, size_t n) {
+	inline std::size_t strxfrm(wchar_t* dest, const wchar_t* src, std::size_t n) {
 		return std::wcsxfrm(dest, src, n);
 	}
 #endif // CLX_USE_WCHAR
