@@ -2,7 +2,7 @@
 /*
  *  json_separator.h
  *
- *  Copyright (c) 2004 - 2009, clown. All rights reserved.
+ *  Copyright (c) 2004 - 2010, clown. All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -29,16 +29,19 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Thu 08 Jan 2009 19:28:00 JST
+ *  Last-modified: Sat 19 Jun 2010 01:58:00 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_JSON_SEPARATOR_H
 #define CLX_JSON_SEPARATOR_H
 
+#include "config.h"
 #include <cctype>
+#include <iterator>
 #include <stdexcept>
 #include "predicate.h"
 #include "lexical_cast.h"
+#include "utf8.h"
 
 namespace clx {
 	/* --------------------------------------------------------------------- */
@@ -74,33 +77,27 @@ namespace clx {
 	
 	namespace detail {
 		/* ----------------------------------------------------------------- */
-		//  utf8
+		/*
+		 *  unicode
+		 *
+		 *  Current encoding is as follows:
+		 *    - char -> UTF-8
+		 *    - wchar_t -> UTF-16
+		 */
 		/* ----------------------------------------------------------------- */
 		template <typename CharT>
-		struct utf8 {
+		struct unicode {
 			static std::basic_string<CharT> convert(int code) {
 				return std::basic_string<CharT>(1, static_cast<CharT>(code));
 			}
 		};
 		
 		template <>
-		struct utf8<char> {
+		struct unicode<char> {
 			static std::basic_string<char> convert(int code) {
 				std::basic_string<char> dest;
-				
-				if(code < 0x0080) { // character 0x0000 - 0x007f...
-					dest.push_back(0x00 | ((code & 0x007f) >> 0));
-				}
-				else if(code < 0x0800) { // character 0x0080 - 0x07ff...
-					dest.push_back(0xc0 | ((code & 0x07c0) >> 6));
-					dest.push_back(0x80 | ((code & 0x003f) >> 0));
-				}
-				else { // character 0x0800 - 0xffff...
-					dest.push_back(0xe0 | ((code & 0x00f000) >> 12));
-					dest.push_back(0x80 | ((code & 0x000fc0) >>  6));
-					dest.push_back(0x80 | ((code & 0x00003f) >>  0));
-				}
-				
+				std::insert_iterator<std::basic_string<char> > out(dest, dest.end());
+				clx::utf8::encode(static_cast<char32_t>(code), out);
 				return dest;
 			}
 		};
@@ -108,8 +105,8 @@ namespace clx {
 		/* ----------------------------------------------------------------- */
 		//  next_string
 		/* ----------------------------------------------------------------- */
-		template <class InputIterator, class CharT>
-		bool next_string(InputIterator& next, InputIterator last, std::basic_string<CharT>& dest) {
+		template <class InIter, class CharT>
+		bool next_string(InIter& next, InIter last, std::basic_string<CharT>& dest) {
 			json_control_charset<CharT> ctrl;
 			
 			++next;
@@ -121,7 +118,7 @@ namespace clx {
 						std::basic_string<CharT> code;
 						for (int i = 0; i < 3; ++i, ++next) code += *next;
 						code += *next;
-						dest += detail::utf8<CharT>::convert(lexical_cast<int>(code, std::ios::hex));
+						dest += detail::unicode<CharT>::convert(lexical_cast<int>(code, std::ios::hex));
 					}
 					else if (*next == ctrl.backspace) dest += LITERAL('\b');
 					else if (*next == ctrl.cr) dest += LITERAL('\r');
@@ -140,8 +137,8 @@ namespace clx {
 		/* ----------------------------------------------------------------- */
 		//  next_member
 		/* ----------------------------------------------------------------- */
-		template <class InputIterator, class CharT>
-		bool next_member(InputIterator& next, InputIterator last,
+		template <class InIter, class CharT>
+		bool next_member(InIter& next, InIter last,
 			std::basic_string<CharT>& dest, CharT beg_char, CharT end_char) {
 			int n = 1;
 			while (next != last && n > 0) {
@@ -170,40 +167,52 @@ namespace clx {
 		
 		void reset() {}
 		
-		template <class InputIterator, class Key, class Token>
-		bool operator()(InputIterator& next, InputIterator last, Key& key, Token& dest) {
+		/* ----------------------------------------------------------------- */
+		/*
+		 *  operator()
+		 *
+		 *  The JSON object allows only pair element. Rule of pair element
+		 *  is "key: value", and key element allows only string (start
+		 *  and end with '"' character). value element allows many kinds
+		 *  of elements... (skip listing :p)
+		 */
+		/* ----------------------------------------------------------------- */
+		template <class InIter, class Key, class Token>
+		bool operator()(InIter& next, InIter last, Key& key, Token& dest) {
+			static const clx::classified_functor space = is_space();
+			
 			if (next == last || (*next != ctrl.lbrace && *next != ctrl.quot)) return false;
 			else if (*next == ctrl.lbrace) ++next;
 			
-			while (next != last && *next != ctrl.colon) {
-				if (*next == ctrl.quot) {
-					if (!detail::next_string(next, last, key)) return false;
-				}
-				else if (!is_space()(*next)) key += *next;
-				++next;
-			}
+			while (next != last && space(*next)) ++next;
+			if (next == last || *next != ctrl.quot) return false;
+			if (!detail::next_string(next, last, key)) return false;
+			++next;
+			
+			if (next == last || *next != ctrl.colon) return false;
 			++next;
 			
 			string_type tmp;
 			while (next != last) {
 				if (*next == ctrl.comma || *next == ctrl.rbrace) {
-					if (!tmp.empty()) dest = lexical_cast<Token>(tmp);
-					return true;
+					++next;
+					break;
 				}
 				else if (*next == ctrl.lbracket) {
-					if (!detail::next_member(next, last, tmp, ctrl.lbracket, ctrl.rbracket)) break;
+					if (!detail::next_member(next, last, tmp, ctrl.lbracket, ctrl.rbracket)) return false;
 				}
 				else if (*next == ctrl.lbrace) {
-					if (!detail::next_member(next, last, tmp, ctrl.lbrace, ctrl.rbrace)) break;
+					if (!detail::next_member(next, last, tmp, ctrl.lbrace, ctrl.rbrace)) return false;
 				}
 				else if (*next == ctrl.quot) {
-					if (!detail::next_string(next, last, tmp)) break;
+					if (!detail::next_string(next, last, tmp)) return false;
 				}
-				else if (!is_space()(*next)) tmp += *next;
+				else if (!space(*next)) tmp += *next;
 				++next;
 			}
 			
-			return false;
+			if (!tmp.empty()) dest = lexical_cast<Token>(tmp);
+			return true;
 		}
 		
 	private:
