@@ -39,8 +39,10 @@
 #ifndef CLX_LEXICAL_CAST_H
 #define CLX_LEXICAL_CAST_H
 
+#include "config.h"
 #include <sstream>
 #include <string>
+#include <ios>
 #include <iomanip>
 #include <iostream>
 #include <typeinfo>
@@ -168,13 +170,12 @@ namespace clx {
 	 */
 	/* --------------------------------------------------------------------- */
 	template <class Type, class Source>
-	Type lexical_cast(const Source& src, std::ios::fmtflags base = std::ios::dec) {
+	inline Type lexical_cast(const Source& src, std::ios::fmtflags base = std::ios::dec) {
 		Type dest;
-		if (typeid(src) == typeid(dest)) return *((Type*)&src); // no needs to convert
-		
+		if (typeid(Source) == typeid(Type)) return *((Type*)&src); // no needs to convert
 		cast_stream<Type, Source> ss(base);
 		if(!(ss << src && ss >> dest)) {
-			throw(bad_lexical_cast(typeid(Source), typeid(Type)));
+			throw bad_lexical_cast(typeid(Source), typeid(Type));
 		}
 		return dest;
 	}
