@@ -29,7 +29,7 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Tue 03 Nov 2009 21:53:03 JST
+ *  Last-modified: Fri 30 Jul 2010 19:49:03 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_WIN32_DATE_TIME_H
@@ -44,6 +44,10 @@
 #include "../tokenizer_func.h"
 #include "../lexical_cast.h"
 
+#if defined(__BORLANDC__)
+#include <time.h>
+#endif
+
 namespace clx {
 	namespace detail {
 		/* ----------------------------------------------------------------- */
@@ -118,8 +122,8 @@ namespace clx {
 		
 		void xstrptime(const char* src, const char* fmt, struct tm* dest) {
 			std::basic_string<char> tmp_fmt(fmt);
-			replace(tmp_fmt, std::basic_string<char>("%F"), std::basic_string<char>("%Y-%m-%d"));
-			replace(tmp_fmt, std::basic_string<char>("%T"), std::basic_string<char>("%H:%M:%S"));
+			clx::replace(tmp_fmt, std::basic_string<char>("%F"), std::basic_string<char>("%Y-%m-%d"));
+			clx::replace(tmp_fmt, std::basic_string<char>("%T"), std::basic_string<char>("%H:%M:%S"));
 			
 			std::basic_string<char> dateset = "aAbByYmdeHkMSjuw";
 			format_separator<char> sep(tmp_fmt, dateset);
